@@ -42,7 +42,6 @@ static const char *const liq_attr_magic = "liq_attr";
 static const char *const liq_image_magic = "liq_image";
 static const char *const liq_result_magic = "liq_result";
 static const char *const liq_remapping_result_magic = "liq_remapping_result";
-static const char *const maniac = "she's a maniac, maniac on the floor";
 static const char *const liq_freed_magic = "free";
 
 #define CHECK_STRUCT_TYPE(attr, kind) {					\
@@ -624,15 +623,11 @@ liq_crash_if_invalid_handle_pointer_given(const liq_attr *user_supplied_pointer,
     if (!user_supplied_pointer) {
         return LIQ_NULL_POINTER;
     }
-
+    /*
     if (user_supplied_pointer->magic_header == liq_freed_magic) {
-	fprintf (stderr, "%s\n", maniac);
-	fprintf (stderr, "pointers ---> %p %p %p %p\n",
-		 user_supplied_pointer, user_supplied_pointer->magic_header,
-		 liq_attr_magic, liq_freed_magic);
 	return LIQ_FREED_POINTER;
     }
-
+    */
     if (user_supplied_pointer->magic_header != expected_magic_header) {
 	return LIQ_INVALID_POINTER;
     }
@@ -670,9 +665,6 @@ liq_error liq_invalid_any (void * any)
     if (error != LIQ_OK) {				\
 	return error;					\
     }							\
-    if (any->magic_header == liq_freed_magic) {		\
-	return LIQ_FREED_POINTER;			\
-    }							\
     if (any->magic_header != liq_ ## any ## _magic) {	\
 	return LIQ_INVALID_POINTER;			\
     }							\
